diff include/freeDiameter/libfdcore.h @ 1071:6ca6cadf209c

Implement the fd_stat_getstats function; changed prototype of fd_fifo_length.
author Sebastien Decugis <sdecugis@freediameter.net>
date Thu, 02 May 2013 11:22:31 +0800
parents 544fa1be79a9
children b36c81e52e9a
line wrap: on
line diff
--- a/include/freeDiameter/libfdcore.h	Thu May 02 11:22:22 2013 +0800
+++ b/include/freeDiameter/libfdcore.h	Thu May 02 11:22:31 2013 +0800
@@ -1096,8 +1096,8 @@
  * PARAMETERS:
  *  stat	  : Which queue is being queried
  *  peer	  : (depending on the stat parameter) which peer is being queried
  *  len	  	  : (out) The number of items in the queue currently
  *  max	  	  : (out) The max number of items the queue accepts before becoming blocking -- 0 means no max.
  *  highest_count : (out) The highest count the queue has reached since startup
  *  total_count	  : (out) Total number of items that this queue has processed (always growing, use deltas for monitoring)
  *  total	  : (out) Cumulated time all items spent in this queue, including blocking time (always growing, use deltas for monitoring)
@@ -1113,7 +1113,7 @@
  *  EINVAL 	: A parameter is invalid.
  */
 int fd_stat_getstats(enum fd_stat_type stat, struct peer_hdr * peer, 
-			int * len, int * max, int * highest_count, long long * total_count, 
+			int * current_count, int * limit_count, int * highest_count, long long * total_count,
 			struct timespec * total, struct timespec * blocking, struct timespec * last);
 
 /*============================================================*/
@@ -1096,8 +1096,8 @@
  *  stat	  : Which queue is being queried
  *  peer	  : (depending on the stat parameter) which peer is being queried
- *  len	  	  : (out) The number of items in the queue currently
- *  max	  	  : (out) The max number of items the queue accepts before becoming blocking -- 0 means no max.
+ *  current_count : (out) The number of items in the queue currently
+ *  limit_count   : (out) The max number of items the queue accepts before becoming blocking -- 0 means no max.
  *  highest_count : (out) The highest count the queue has reached since startup
  *  total_count	  : (out) Total number of items that this queue has processed (always growing, use deltas for monitoring)
"Welcome to our mercurial repository"